@@ -25,6 +25,7 @@ from buybackprogram.notification import (
 from .app_settings import (
     BUYBACKPROGRAM_TRACKING_PREFILL,
     BUYBACKPROGRAM_TRACK_PREFILL_CONTRACTS,
+    get_site_url,
 )
 
 from .decorators import fetch_token_for_owner
@@ -301,6 +302,7 @@ class Owner(models.Model):
                 logger.debug("Got corporations for contract owner: %s" % corporations)
 
                 objs = []
+                items = []
 
                 # Prepare objects for bulk create
                 for item in contract_items:
@@ -315,6 +317,12 @@ class Owner(models.Model):
 
                     objs.append(contract_item)
 
+                    items.append(
+                        str(EveType.objects.get(id=item["type_id"]))
+                        + " x "
+                        + str(item["quantity"])
+                    )
+
                 try:
                     ContractItem.objects.bulk_create(objs)
                     logger.debug(
@@ -346,17 +354,35 @@ class Owner(models.Model):
                 notes = str()
 
                 if notifications:
-                    notes += "\n\n**Notes**:\n"
                     for note in notifications:
                         notes += str(note.message)
                         notes += "\n\n"
 
+                logger.debug("Contract contains %s" % "\n".join(items))
+
+                contract_item_list = "\n".join(items)
+                contract_url = (
+                    get_site_url()
+                    + "/buybackprogram/tracking/"
+                    + tracking.tracking_number
+                )
+
+                # Limit contract items to fit into embed limitations
+                if len(contract_item_list) > 2000:
+                    contract_item_list = (
+                        contract_item_list
+                        + "\n[See all items ...]("
+                        + contract_url
+                        + ")"
+                    )
+
                 user_message = {
-                    "title": "New buyback contract assigned",
-                    "description": "A new contract with tracking number {0} has been assigned to buyback program {1}.{2}".format(
-                        tracking.tracking_number,
-                        tracking.program.name,
-                        notes,
+                    "contract": obj,
+                    "contract_items": contract_item_list,
+                    "tracking": tracking,
+                    "notes": notes,
+                    "title": "New buyback contract assigned for program {0}".format(
+                        tracking.program.name
                     ),
                     "color": 0x5BC0DE,
                     "value": intcomma(int(contract["price"])),
@@ -364,7 +390,6 @@ class Owner(models.Model):
                     "assigned_from": EveEntity.objects.resolve_name(
                         contract["issuer_id"]
                     ),
-                    "footer": "Hint: You can disable these notifications from your program settings",
                 }
 
                 # If tracking is active and we should send a message for our users
@@ -437,28 +462,24 @@ class Owner(models.Model):
                     )
 
                     notes = str()
+                    items = []
 
                     if notifications:
-                        notes += "\n\n**Notes**:\n"
                         for note in notifications:
                             notes += str(note.message)
                             notes += "\n\n"
 
                     user_message = {
-                        "title": "Buyback contract {0}".format(status),
-                        "description": "Your outstanding buyback contract {0} has been {1} by {2}.{3}".format(
-                            tracking.tracking_number,
-                            status,
-                            self.character.character,
-                            notes,
-                        ),
+                        "contract": obj,
+                        "tracking": tracking,
+                        "title": "Your buyback contract has been {0}".format(status),
                         "color": color,
+                        "notes": notes,
                         "value": intcomma(int(contract["price"])),
                         "assigned_to": assigned_to,
                         "assigned_from": EveEntity.objects.resolve_name(
                             contract["issuer_id"]
                         ),
-                        "footer": "Hint: You can disable these notifications from your buybackprogram settings",
                     }
 
                     send_user_notification(
@@ -1214,7 +1235,7 @@ class ItemPrices(models.Model):
 class Contract(models.Model):
     assignee_id = models.IntegerField()
     availability = models.CharField(max_length=20)
-    contract_id = models.IntegerField()
+    contract_id = models.IntegerField(unique=True)
     date_completed = models.DateTimeField(null=True)
     date_expired = models.DateTimeField(null=True)
     date_issued = models.DateTimeField()
@@ -1227,9 +1248,10 @@ class Contract(models.Model):
     status = models.CharField(max_length=30)
     title = models.CharField(max_length=128)
     volume = models.BigIntegerField()
-    no_tracking = models.BooleanField(
-        default=False,
-    )
+    no_tracking = models.BooleanField(default=False)
+
+    def __str__(self) -> str:
+        return str(self.contract_id)
 
 
 class ContractItem(models.Model):
